//
// "$Id: Fl_File_Chooser.H 9582 2012-06-10 11:10:24Z matt $"
//
// Fl_File_Chooser dialog for the Fast Light Tool Kit (FLTK).
// FLTK 123 wrapper finished
//  - this class has no virtual functions, so we simply derive form FLTK3
//  - this file was originally generated by Fluid, later hand-edited
//
// Copyright 1998-2012 by Bill Spitzak and others.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
// Please report all bugs and problems on the following page:
//
//     http://www.fltk.org/str.php
//

#ifndef Fl_File_Chooser_H
#define Fl_File_Chooser_H

#include <fltk3/FileChooser.h>
#include <fltk3/FileBrowser.h>

#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <FL/Fl_Group.H>
#include <FL/Fl_Choice.H>
#include <FL/Fl_Menu_Button.H>
#include <FL/Fl_Button.H>
#include <FL/Fl_Preferences.H>
#include <FL/Fl_Tile.H>
#include <FL/Fl_File_Browser.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Check_Button.H>
#include <FL/Fl_File_Input.H>
#include <FL/Fl_Return_Button.H>
#include <FL/fl_ask.H>


class FL_EXPORT Fl_File_Chooser : public fltk3::FileChooser {
    
  static void browser_cb(Fl_Widget *w1, void *v) {
    fltk3::FileBrowser* o = (fltk3::FileBrowser*)(w1->_p);
    fltk3::FileChooser::cb_fileList(o,v);
  }
  
  static void window_cb(Fl_Widget *w1, void *v) {
    fltk3::DoubleWindow* o = (fltk3::DoubleWindow*)(w1->_p);
    fltk3::FileChooser::cb_window(o,v);
  }
  
  static void preview_cb(Fl_Widget *w1, void *v) {
    fltk3::CheckButton* o = (fltk3::CheckButton*)(w1->_p);
    fltk3::FileChooser::cb_previewButton(o,v);
  }
  
  static void hidden_cb(Fl_Widget *w1, void *v) {
    fltk3::CheckButton* o = (fltk3::CheckButton*)(w1->_p);
    fltk3::FileChooser::cb_showHiddenButton(o,v);
  }
  
  static void new_cb(Fl_Widget *w1, void *v) {
    fltk3::Button* o = (fltk3::Button*)(w1->_p);
    fltk3::FileChooser::cb_newButton(o,v);
  }
  
public:
  
  enum { SINGLE = 0, MULTI = 1, CREATE = 2, DIRECTORY = 4 }; 
  Fl_Check_Button *previewButton;
  Fl_Button *newButton;
  Fl_Check_Button *showHiddenButton;
  
  Fl_File_Chooser(const char *d, const char *p, int t, const char *title)
  : fltk3::FileChooser(d, p, t, title) { 
    fltk3::FileBrowser *b3 = fltk3::FileChooser::browser();
    Fl_Widget *b1 = new Fl_File_Browser();
    b3->wrapper(b1);
    b1->_p = b3;
    // when b3's callback will be called it will be sent b1 as 1st argument
    // thus we change b3's callback accordingly
    b3->callback((fltk3::Callback*)browser_cb);
    // wrap the internal fltk3::Window object with an FLTK1 widget
    fltk3::Window* w3 = b3->window();
    Fl_Widget *w1 = new Fl_Window();
    w3->wrapper(w1);
    w1->_p = w3;
    // when w3's callback will be called it will be sent w1 as 1st argument
    // thus we change w3's callback accordingly
    w3->callback((fltk3::Callback*)window_cb);
    
    previewButton = new  Fl_Check_Button();
    fltk3::FileChooser::previewButton->wrapper(previewButton);
    previewButton->_p = fltk3::FileChooser::previewButton;
    fltk3::FileChooser::previewButton->callback((fltk3::Callback*)preview_cb);
    
    newButton = new  Fl_Button();
    fltk3::FileChooser::newButton->wrapper(newButton);
    newButton->_p = fltk3::FileChooser::newButton;
    fltk3::FileChooser::newButton->callback((fltk3::Callback*)new_cb);
    
    showHiddenButton = new  Fl_Check_Button();
    fltk3::FileChooser::showHiddenButton->wrapper(showHiddenButton);
    showHiddenButton->_p = fltk3::FileChooser::showHiddenButton;
    fltk3::FileChooser::showHiddenButton->callback((fltk3::Callback*)hidden_cb);
  }
  
  Fl_Widget* add_extra(Fl_Widget* gr) {
    fltk3::Widget *w3 = fltk3::FileChooser::add_extra(fltk3::_1to3_widget(gr));
    if (w3 && !w3->wrapper()) {
      Fl_Widget *w1 = new Fl_Widget();
      w3->wrapper(w1);
      w1->_p = w3;
    }
    return fltk3::_3to1_widget(w3);
  }
  
  Fl_File_Browser *browser(void) {
    return (Fl_File_Browser*)fltk3::_3to1_widget(fltk3::FileChooser::browser());
  }
  
  void callback(void (*cb)(Fl_File_Chooser *, void *), void *d = 0) {
    fltk3::FileChooser::callback((void (*)(fltk3::FileChooser*, void*))cb, d);
  }
};
        

inline char *fl_dir_chooser(const char *message,const char *fname,int relative=0) {
  return fltk3::dir_chooser(message, fname, relative);
}

inline char *fl_file_chooser(const char *message,const char *pat,const char *fname,int relative=0) {
  return fltk3::file_chooser(message, pat, fname, relative);
}

inline  void fl_file_chooser_callback(void (*cb)(const char*)) {
  fltk3::file_chooser_callback(cb);
}

inline void fl_file_chooser_ok_label(const char*l) {
  fltk3::file_chooser_ok_label(l);
}

#endif

//
// End of "$Id: Fl_File_Chooser.H 9582 2012-06-10 11:10:24Z matt $".
//
